.. AUTO-GENERATED FILE -- DO NOT EDIT!

bart.bart
=========

Module: :mod:`bart.bart`
------------------------
Inheritance diagram for ``ISLP.bart.bart``:

.. inheritance-diagram:: ISLP.bart.bart 
   :parts: 3

.. automodule:: ISLP.bart.bart

.. currentmodule:: ISLP.bart.bart

Classes
-------

:class:`BART`
~~~~~~~~~~~~~


.. autoclass:: BART
  :members:
  :undoc-members:
  :show-inheritance:
  :inherited-members:

  .. automethod:: __init__

:class:`SampleSplittingVariable`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


.. autoclass:: SampleSplittingVariable
  :members:
  :undoc-members:
  :show-inheritance:
  :inherited-members:

  .. automethod:: __init__
